@@ -17,14 +17,13 @@
 #Ouvre un terminal sur une machine distante
 """Ouvre un terminal sur une machine distante"""
 
-#==============================================================================
-# Nos imports
-#==============================================================================
 import sys
 import stat
 from os import linesep, chmod, sep
 from os.path import expanduser, abspath, join
 
+SSHOPTS = '-o NoHostAuthenticationForLocalhost=yes -o StrictHostKeyChecking=no'
+
 class Terminal:
     """Ouvre un shell sur une machine distante"""
 
@@ -32,15 +31,14 @@ class Terminal:
         self._ordres = []
         self._premiereligne = True
         self._commande = False
-        self._utilisateurroot = False
         self._destination = ''
         self._machinefinale = ''
         self._extfichier = '.sh'
         self._jetons = {}
         self._indice = 0
         delai = opts.lesoptions()[0].delai
-        self._entetel1 = '#!/usr/bin/expect -f\n'
-        self._entetel2 = 'set timeout %s\n\n' % str(delai)
+        self._entetel1 = '#!/usr/bin/expect -f%s' % linesep
+        self._entetel2 = 'set timeout %s%s%s' % (str(delai), linesep, linesep)
         self._script = [self._entetel1, self._entetel2]
         if opts.lesoptions()[0].repsortie is not None:
             self._destination = opts.lesoptions()[0].repsortie + sep
@@ -135,9 +133,9 @@ exceeds 64 characters")
 			self._script[-1] != self._entetel2) or (num + 1 == len(self._ordres) and 
 				self._script[-1] != self._entetel2):
             if not self._commande:
-                self._script.append('interact +++ return\n')
+                self._script.append('interact +++ return%s' % linesep)
             else:
-                self._script.append('expect eof\n')
+                self._script.append('expect eof%s' % linesep)
             resultat = abspath(join(self._destination,
                  ''.join([self._machinefinale, self._extfichier])))
             try:
@@ -149,7 +147,6 @@ exceeds 64 characters")
             self._script = [self._entetel1, self._entetel2]
             self._premiereligne = True
             self._commande = False
-            self._utilisateurroot = False
 
     def interprete_ordres(self, num):
         """On interprete un ordre"""
@@ -165,86 +162,76 @@ exceeds 64 characters")
                     self._machinefinale, port = self._machinefinale.split(':')
                     machine = ligne.split()[0].split(':')[0]
                 if self._premiereligne:
-                    if port == '':
-                        self._script.append('spawn ssh %s\n' % machine)
+                    if not port:
+                        self._script.append('spawn ssh %s %s%s' % (SSHOPTS, machine, linesep))
                         self._premiereligne = False
                     else:
-                        self._script.append('spawn ssh -p %s %s\n' %
-                                                 (port, machine))
+                        self._script.append('spawn ssh -p %s %s %s%s' %
+                                                 (port, SSHOPTS, machine, linesep))
                         self._premiereligne = False
                 else:
-                    if port == '':
-                        self._script.append('send -- "ssh %s\\r"\n' % machine)
+                    if not port:
+                        self._script.append('send -- "ssh %s %s\\r"%s' % 
+                                            (SSHOPTS, machine, linesep))
                     else:
-                        self._script.append('send -- "ssh -p %s %s\\r"\n' %
-                                                     (port, machine))
+                        self._script.append('send -- "ssh -p %s %s %s\\r"%s' %
+                                                     (port, SSHOPTS, machine, linesep))
                 if ligne.split()[-1] == '-c':
                     self.avec_commande(ligne)
-                    self._commande = True
+                    self._commande = True,
                 else:
                     self.sans_commande(ligne)
 
     def avec_commande(self, ligne):
         """La ligne du fichier d'ordre contient le symbole commande"""
         if len(ligne.split()) == 2:
-            self._script.append('expect "$"\n')
+            self.prepare_prompt()
         if len(ligne.split()) == 3:
             self.envoie_motdepasse_ssh(ligne.split()[1])
-            self._script.append('expect "$"\n')
         if len(ligne.split()) ==  4 :
-            self._script.append('expect "$"\n')
+            self.prepare_prompt()
             self.change_utilisateur(ligne.split()[1], ligne.split()[2])
         if len(ligne.split()) ==  5 :
             self.envoie_motdepasse_ssh(ligne.split()[1])
-            self._script.append('expect "$"\n')
             self.change_utilisateur(ligne.split()[2], ligne.split()[3])
 
     def sans_commande(self, ligne):
         """La ligne du fichier d'ordre ne contient pas le symbole commande"""
         if len(ligne.split()) == 1:
-            self._script.append('expect "$"\n')
+            self.prepare_prompt()
         if len(ligne.split()) == 2:
             self.envoie_motdepasse_ssh(ligne.split()[1])
-            self._script.append('expect "$"\n')
         if len(ligne.split()) ==  3 :
-            self._script.append('expect "$"\n')
+            self.prepare_prompt()
             self.change_utilisateur(ligne.split()[1], ligne.split()[2])
         if len(ligne.split()) ==  4 :
             self.envoie_motdepasse_ssh(ligne.split()[1])
-            self._script.append('expect "$"\n')
             self.change_utilisateur(ligne.split()[2], ligne.split()[3])
 
     def traite_commande(self, ligne):
         """Traite la commande contenue dans la ligne courante"""
-        self._script.append('send -- "%s\\r"\n' % ligne.rstrip(linesep))
+        self._script.append('send -- "%s\\r"%s' % (ligne.rstrip(linesep), linesep))
         self.prepare_prompt()
 
     def change_utilisateur(self, utilisateur, motdepasse):
         """Génère le script pour changer d'utilisateur"""
-        #motdepasse = motdepasse.replace('"','\\"')
         if motdepasse in self._jetons:
             motdepasse = self._jetons[motdepasse]
-        self._script.append('send -- "su - %s\\r"\n' % utilisateur)
-        self._script.append('expect "assword:"\n')
-        self._script.append('send -- "%s\\r"\n' % motdepasse)
-        if utilisateur == 'root':
-            self._utilisateurroot = True
-        else:
-            self._utilisateurroot = False
+        self._script.append('send -- "su - %s\\r"%s' % (utilisateur, linesep))
+        self._script.append('expect ":"%s' % linesep)
+        self._script.append('send -- "%s\\r"%s' % (motdepasse, linesep))
         self.prepare_prompt()
 
     def prepare_prompt(self):
         """Prépare le prompt en fonction de l'identité de l'utilisateur""" 
-        if self._utilisateurroot:
-            self._script.append('expect "#"\n')
-        else:
-            self._script.append('expect "$"\n')
+        self._script.append('expect -re  "(%s|#|\\\\$) $"%s' % ('%', linesep)) 
+        
 
     def envoie_motdepasse_ssh(self, motdepasse):
         """Envoie le mot de passe lors d'une connexion ssh"""
-        #motdepasse = motdepasse.replace('"','\\"')
         if motdepasse in self._jetons:
             motdepasse = self._jetons[motdepasse]
-        self._script.append('expect {\n "assword:" {send -- "%s\\r"}\n \
-"yes/no" {send -- "yes\\r";exp_continue}\n}\n' % motdepasse)
-
+        self._script.append('expect -re {@[^\\n]*:}%s' % linesep) 
+        self._script.append('send -- "%s\\r"%s' % (motdepasse, linesep))
+        self.prepare_prompt()
+        
